tsum.test = function (mean.x, s.x = NULL, n.x = NULL, mean.y = NULL, s.y = NULL, 
    n.y = NULL, alternative = "two.sided", mu = 0, var.equal = TRUE, 
    conf.level = 0.95) 
{
    alt.expanded <- if (!missing(alternative)) 
        char.expand(alternative, c("two.sided", "greater", "less"), 
            stop("argument 'alternative' must match one of \"greater\", \"less\", \"two.sided\"."))
    else alternative
    if (!missing(mu)) 
        if ((length(mu) != 1) || !is.finite(mu)) 
            stop("argument 'mu' must be a single finite numeric value.")
    if (!missing(conf.level)) 
        if ((length(conf.level) != 1) || !is.finite(conf.level) || 
            (conf.level <= 0) || (conf.level >= 1)) 
            stop("argument 'conf.level' must be a single number greater than zero and less than one \n.")
    if (!is.null(mean.x) && is.null(mean.y) && is.null(n.x) && 
        is.null(s.x)) 
        stop("You must enter the value for both s.x and n.x")
    if (is.null(n.x) && !is.null(mean.x) && !is.null(s.x) && 
        is.null(mean.y)) 
        stop("You must enter the value for n.x")
    if (is.null(s.x) && !is.null(mean.x) && !is.null(n.x) && 
        is.null(mean.y)) 
        stop("You must enter the value for s.x")
    if (is.null(n.y) && !is.null(mean.x) && !is.null(mean.y) && 
        !is.null(s.y) && !is.null(s.x) && !is.null(n.x)) 
        stop("You must enter the value for n.y")
    if (is.null(n.y) && is.null(n.x) && !is.null(mean.x) && !is.null(mean.y) && 
        !is.null(s.y) && !is.null(s.x)) 
        stop("You must enter the value for both n.x and n.y")
    if (is.null(s.x) && is.null(s.y) && !is.null(mean.x) && !is.null(mean.y) && 
        !is.null(n.x) && !is.null(n.y)) 
        stop("You must enter the value for both s.x and s.y")
    if (!is.null(s.x) && is.null(s.y) && !is.null(mean.x) && 
        !is.null(mean.y) && !is.null(n.x) && !is.null(n.y)) 
        stop("You must enter the value for s.y")
    if (is.null(n.y) && is.null(s.y) && !is.null(mean.x) && !is.null(mean.y) && 
        !is.null(s.x) && !is.null(n.x)) 
        stop("You must enter the value for both s.y and n.y")
    alpha <- 1 - conf.level
    if (is.null(mean.y)) {
        if (!var.equal) 
            warning("argument 'var.equal' ignored for one-sample test.")
        conf.int.xbar <- mean.x
        conf.int.s <- sqrt(s.x^2/n.x)
        ret.val <- list(statistic = (conf.int.xbar - mu)/conf.int.s, 
            parameters = n.x - 1, estimate = conf.int.xbar, null.value = mu, 
            alternative = alt.expanded, method = "One-sample t-Test", 
            data.name = c("Summarized x"))
        names(ret.val$estimate) <- "mean of x"
        names(ret.val$null.value) <- "mean"
    }
    else {
        mean.x <- mean.x
        mean.y <- mean.y
        conf.int.xbar <- mean.x - mean.y
        var.x <- s.x^2
        var.y <- s.y^2
        conf.int.s <- if (var.equal) 
            sqrt((((n.x - 1) * var.x + (n.y - 1) * var.y) * (1/n.x + 
                1/n.y))/(n.x + n.y - 2))
        else sqrt((var.x/n.x) + (var.y/n.y))
        ret.val <- c(if (var.equal) list(method = "Standard Two-Sample t-Test", 
            parameters = n.x + n.y - 2) else list(method = "Welch Modified Two-Sample t-Test", 
            parameters = {
                const <- 1/(1 + (n.x * var.y)/(n.y * var.x))
                1/((const^2)/(n.x - 1) + ((1 - const)^2)/(n.y - 
                  1))
            }), list(statistic = (conf.int.xbar - mu)/conf.int.s, 
            estimate = c(mean.x, mean.y), null.value = mu, alternative = alt.expanded, 
            data.name = paste("Summarized ", deparse(substitute(x)), 
                " and ", deparse(substitute(y)), sep = "")))
        names(ret.val$estimate) <- c("mean of x", "mean of y")
        names(ret.val$null.value) <- "difference in means"
    }
    ret.val <- c(ret.val, switch(alt.expanded, two.sided = {
        conf.int.hw <- qt((1 - alpha/2), ret.val$parameters) * 
            conf.int.s
        list(p.value = 2 * pt(-abs(ret.val$statistic), ret.val$parameters), 
            conf.int = c(conf.int.xbar - conf.int.hw, conf.int.xbar + 
                conf.int.hw))
    }, greater = {
        list(p.value = 1 - pt(ret.val$statistic, ret.val$parameters), 
            conf.int = c(conf.int.xbar - qt((1 - alpha), ret.val$parameters) * 
                conf.int.s, NA))
    }, less = {
        list(p.value = pt(ret.val$statistic, ret.val$parameters), 
            conf.int = c(NA, conf.int.xbar + qt((1 - alpha), 
                ret.val$parameters) * conf.int.s))
    }))
    names(ret.val$statistic) <- "t"
    names(ret.val$parameters) <- "df"
    attr(ret.val$conf.int, "conf.level") <- conf.level
    ret.val <- ret.val[c("statistic", "parameters", "p.value", 
        "conf.int", "estimate", "null.value", "alternative", 
        "method", "data.name")]
    oldClass(ret.val) <- "htest"
    return(ret.val)
}


zsum.test = function (mean.x, sigma.x = NULL, n.x = NULL, mean.y = NULL, 
    sigma.y = NULL, n.y = NULL, alternative = "two.sided", mu = 0, 
    conf.level = 0.95) 
{
    choices <- c("two.sided", "greater", "less")
    alt <- pmatch(alternative, choices)
    alternative <- choices[alt]
    if (length(alternative) > 1 || is.na(alternative)) 
        stop("alternative must be one \"greater\", \"less\", \"two.sided\"")
    if (!missing(mu)) 
        if (length(mu) != 1 || is.na(mu)) 
            stop("mu must be a single number")
    if (!is.null(mean.x) && is.null(mean.y) && is.null(n.x) && 
        is.null(sigma.x)) 
        stop("You must enter the value for both sigma.x and n.x")
    if (is.null(n.x) && !is.null(mean.x) && !is.null(sigma.x) && 
        is.null(mean.y)) 
        stop("You must enter the value for n.x")
    if (is.null(sigma.x) && !is.null(mean.x) && !is.null(n.x) && 
        is.null(mean.y)) 
        stop("You must enter the value for sigma.x")
    if (is.null(n.y) && !is.null(mean.x) && !is.null(mean.y) && 
        !is.null(sigma.y) && !is.null(sigma.x) && !is.null(n.x)) 
        stop("You must enter the value for n.y")
    if (is.null(n.y) && is.null(n.x) && !is.null(mean.x) && !is.null(mean.y) && 
        !is.null(sigma.y) && !is.null(sigma.x)) 
        stop("You must enter the value for both n.x and n.y")
    if (is.null(sigma.x) && is.null(sigma.y) && !is.null(mean.x) && 
        !is.null(mean.y) && !is.null(n.x) && !is.null(n.y)) 
        stop("You must enter the value for both sigma.x and sigma.y")
    if (!is.null(sigma.x) && is.null(sigma.y) && !is.null(mean.x) && 
        !is.null(mean.y) && !is.null(n.x) && !is.null(n.y)) 
        stop("You must enter the value for sigma.y")
    if (is.null(n.y) && is.null(sigma.y) && !is.null(mean.x) && 
        !is.null(mean.y) && !is.null(sigma.x) && !is.null(n.x)) 
        stop("You must enter the value for both sigma.y and n.y")
    if (!missing(conf.level)) 
        if (length(conf.level) != 1 || is.na(conf.level) || conf.level < 
            0 || conf.level > 1) 
            stop("conf.level must be a number between 0 and 1")
    if (!is.null(mean.y)) {
        dname <- c("Summarized x and y")
    }
    else {
        dname <- c("Summarized x")
    }
    n.x
    if (n.x <= 1) 
        stop("not enough x observations")
    estimate <- mean.x
    if (is.null(mean.y)) {
        stderr <- sigma.x/sqrt(n.x)
        zobs <- (mean.x - mu)/stderr
        method <- c("One-sample z-Test")
        names(estimate) <- c("mean of x")
    }
    else {
        n.y
        if (n.y <= 1) 
            stop("not enough y observations")
        method <- c("Two-sample z-Test")
        estimate <- c(mean.x, mean.y)
        names(estimate) <- c("mean of x", "mean of y")
        stderr <- sqrt(((sigma.x^2)/n.x) + ((sigma.y^2)/n.y))
        zobs <- (mean.x - mean.y - mu)/stderr
    }
    if (alternative == "less") {
        pval <- pnorm(zobs)
        cint <- c(NA, zobs * stderr + qnorm(conf.level) * stderr)
    }
    else if (alternative == "greater") {
        pval <- 1 - pnorm(zobs)
        cint <- c(zobs * stderr - qnorm(conf.level) * stderr, 
            NA)
    }
    else {
        pval <- 2 * pnorm(-abs(zobs))
        alpha <- 1 - conf.level
        cint <- c(zobs * stderr - qnorm((1 - alpha/2)) * stderr, 
            zobs * stderr + qnorm((1 - alpha/2)) * stderr)
    }
    cint <- cint + mu
    names(zobs) <- "z"
    if (!is.null(mean.y)) 
        names(mu) <- "difference in means"
    else names(mu) <- "mean"
    attr(cint, "conf.level") <- conf.level
    rval <- list(statistic = zobs, p.value = pval, conf.int = cint, 
        estimate = estimate, null.value = mu, alternative = alternative, 
        method = method, data.name = dname)
    attr(rval, "class") <- "htest"
    return(rval)
}


z.test = function (x, y = NULL, alternative = "two.sided", mu = 0, sigma.x = NULL, 
    sigma.y = NULL, conf.level = 0.95) 
{
    choices <- c("two.sided", "greater", "less")
    alt <- pmatch(alternative, choices)
    alternative <- choices[alt]
    if (length(alternative) > 1 || is.na(alternative)) 
        stop("alternative must be one \"greater\", \"less\", \"two.sided\"")
    if (!missing(mu)) 
        if (length(mu) != 1 || is.na(mu)) 
            stop("mu must be a single number")
    if (is.null(sigma.x) && !is.null(x) && is.null(y)) 
        stop("You must enter the value for sigma.x")
    if (!is.null(y) && is.null(sigma.y) || is.null(sigma.x)) 
        stop("You must enter values for both sigma.x and sigma.y")
    if (!missing(conf.level)) 
        if (length(conf.level) != 1 || is.na(conf.level) || conf.level < 
            0 || conf.level > 1) 
            stop("conf.level must be a number between 0 and 1")
    if (!is.null(y)) {
        dname <- paste(deparse(substitute(x)), "and", paste(deparse(substitute(y))))
    }
    else {
        dname <- deparse(substitute(x))
    }
    nx <- length(x)
    if (nx <= 2) 
        stop("not enough x observations")
    mx <- mean(x)
    estimate <- mx
    if (is.null(y)) {
        stderr <- sigma.x/sqrt(nx)
        zobs <- (mx - mu)/stderr
        method <- c("One-sample z-Test")
        names(estimate) <- c("mean of x")
    }
    else {
        ny <- length(y)
        if (ny <= 2) 
            stop("not enough y observations")
        my <- mean(y)
        method <- c("Two-sample z-Test")
        estimate <- c(mx, my)
        names(estimate) <- c("mean of x", "mean of y")
        stderr <- sqrt(((sigma.x^2)/nx) + ((sigma.y^2)/ny))
        zobs <- (mx - my - mu)/stderr
    }
    if (alternative == "less") {
        pval <- pnorm(zobs)
        cint <- c(NA, zobs * stderr + qnorm(conf.level) * stderr)
    }
    else if (alternative == "greater") {
        pval <- 1 - pnorm(zobs)
        cint <- c(zobs * stderr - qnorm(conf.level) * stderr, 
            NA)
    }
    else {
        pval <- 2 * pnorm(-abs(zobs))
        alpha <- 1 - conf.level
        cint <- c(zobs * stderr - qnorm((1 - alpha/2)) * stderr, 
            zobs * stderr + qnorm((1 - alpha/2)) * stderr)
    }
    cint <- cint + mu
    names(zobs) <- "z"
    if (!is.null(y)) 
        names(mu) <- "difference in means"
    else names(mu) <- "mean"
    attr(cint, "conf.level") <- conf.level
    rval <- list(statistic = zobs, p.value = pval, conf.int = cint, 
        estimate = estimate, null.value = mu, alternative = alternative, 
        method = method, data.name = dname)
    attr(rval, "class") <- "htest"
    return(rval)
}
